aboutsummaryrefslogtreecommitdiff
path: root/Docker/entrypoint.sh
diff options
context:
space:
mode:
authorGravatar Mossroy <mossroy@mossroy.fr> 2023-10-25 16:23:03 +0200
committerGravatar GitHub <noreply@github.com> 2023-10-25 16:23:03 +0200
commit5374df384a032e91f09d53291c879ee19da99714 (patch)
treecf04a1638d0b5279c4692a1dc9468301459da909 /Docker/entrypoint.sh
parent280a1e11556bd22f3640facc12ec5bdaa5d10d90 (diff)
Use RemoteIPInternalProxy directive of remoteip Apache module (#5740)
* Use RemoteIPInternalProxy directive of remoteip Apache module instead of RemoteIPTrustedProxy directive To allow internal IPs to be trusted: for internal clients, and also for the case of chained internal reverse-proxies Fixes #5726 * One last reference forgotten --------- Co-authored-by: Alexandre Alapetite <alexandre@alapetite.fr>
Diffstat (limited to 'Docker/entrypoint.sh')
-rwxr-xr-xDocker/entrypoint.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/Docker/entrypoint.sh b/Docker/entrypoint.sh
index c17d0d445..958fb4b40 100755
--- a/Docker/entrypoint.sh
+++ b/Docker/entrypoint.sh
@@ -13,11 +13,11 @@ fi
if [ -n "$TRUSTED_PROXY" ]; then
if [ "$TRUSTED_PROXY" = "0" ]; then
# Disable RemoteIPHeader and RemoteIPTrustedProxy
find /etc/apache2/ -type f -name FreshRSS.Apache.conf -exec sed -r -i "/^\s*RemoteIP.*$/s/^/#/" {} \;
else
- # Custom list for RemoteIPTrustedProxy
- find /etc/apache2/ -type f -name FreshRSS.Apache.conf -exec sed -r -i "\\#^\s*RemoteIPTrustedProxy#s#^.*#\tRemoteIPTrustedProxy $TRUSTED_PROXY#" {} \;
+ # Custom list for RemoteIPInternalProxy
+ find /etc/apache2/ -type f -name FreshRSS.Apache.conf -exec sed -r -i "\\#^\s*RemoteIPInternalProxy#s#^.*#\tRemoteIPInternalProxy $TRUSTED_PROXY#" {} \;
fi
fi
@@ -13,11 +13,11 @@ fi
if [ -n "$TRUSTED_PROXY" ]; then
if [ "$TRUSTED_PROXY" = "0" ]; then
- # Disable RemoteIPHeader and RemoteIPTrustedProxy
+ # Disable RemoteIPHeader and RemoteIPInternalProxy
find /etc/apache2/ -type f -name FreshRSS.Apache.conf -exec sed -r -i "/^\s*RemoteIP.*$/s/^/#/" {} \;
else